==> certmanager-model-v1alpha2-6.7.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderAcmeDNSBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderAcmeDNSBuilder extends ACMEIssuerDNS01ProviderAcmeDNSFluentImpl<ACMEIssuerDNS01ProviderAcmeDNSBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderAcmeDNS,ACMEIssuerDNS01ProviderAcmeDNSBuilder>{
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderAcmeDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderAcmeDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAcmeDNS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAccountSecretRef(instance.getAccountSecretRef());
      fluent.withHost(instance.getHost());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNS instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderAcmeDNS build() {
    ACMEIssuerDNS01ProviderAcmeDNS buildable = new ACMEIssuerDNS01ProviderAcmeDNS(fluent.getAccountSecretRef(),fluent.getHost());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderAcmeDNSBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderAcmeDNSBuilder extends ACMEIssuerDNS01ProviderAcmeDNSFluent<ACMEIssuerDNS01ProviderAcmeDNSBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderAcmeDNS,ACMEIssuerDNS01ProviderAcmeDNSBuilder>{
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderAcmeDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderAcmeDNS(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent,ACMEIssuerDNS01ProviderAcmeDNS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderAcmeDNS());

    if (instance != null) {
      fluent.withAccountSecretRef(instance.getAccountSecretRef());
      fluent.withHost(instance.getHost());
      fluent.withAccountSecretRef(instance.getAccountSecretRef());
      fluent.withHost(instance.getHost());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderAcmeDNSBuilder(ACMEIssuerDNS01ProviderAcmeDNS instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderAcmeDNS());

    if (instance != null) {
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderAcmeDNSFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderAcmeDNS build() {
    ACMEIssuerDNS01ProviderAcmeDNS buildable = new ACMEIssuerDNS01ProviderAcmeDNS(fluent.buildAccountSecretRef(),fluent.getHost());
    return buildable;
  }
  
}
